@@ -8,11 +8,11 @@ import jsii
 import jsii.compat
 import publication
 
-import aws_cdk.core
-import aws_cdk.region_info
-import constructs
+import aws_cdk.core._jsii
+import aws_cdk.region_info._jsii
+import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-iam", "1.42.1", __name__[0:-6], "aws-iam@1.42.1.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-iam", "1.47.0", __name__[0:-6], "aws-iam@1.47.0.jsii.tgz")
 
 __all__ = [
     "__jsii_assembly__",
